package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````PA4``#0```#DD````````#0`(``*
M`"@`%P`6``8````T````-````#0```!``0``0`$```0````$`````P```'0!
M``!T`0``=`$``!<````7````!`````$````!````````````````````0`\`
M`$`/```$`````!````$`````$````!`````0``!%*@``12H```4`````$```
M`0````!`````0````$```"Q,```L3```!``````0```!````[(T``.R=``#L
MG0``.`(``(@2```&`````!````(```#\C0``_)T``/R=``#0````T`````8`
M```$````4.5T9"!_```@?P``('\``-P```#<````!`````0```!1Y71D````
M```````````````````````&````$````%+E=&3LC0``[)T``.R=```4`@``
M%`(```0````!````+VQI8B]L9"UM=7-L+6DS.#8N<V\N,0``$0```$L````$
M````!P````"!``";1`1)2(X0(8J$!,@`````2P```$\```!3````5````%D`
M``!:````6P````````!=``````````````!>````7P```&``````````````
M`&I_FGSJT^\.SMY'+6_%WQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\L
ML@&+;^)'Q@&[XY)\5<,\TF>OS&:(!W#30T75[#-BV^U_J9R;X:<""J/@^TD`
M````````````````````#```````````````$@```+4!`````````````!(`
M```4```````````````1````VP$`````````````$0```%<!````````````
M`!(````;```````````````2````E`$`````````````$@```",`````````
M`````!(````J```````````````2````Z`$`````````````$@```*`!````
M`````````!(````N`P`````````````A````,P``````````````$@```#D`
M`````````````!(```!````````````````2````]`(`````````````$@``
M`.4"`````````````!(```!M`@`````````````2````1P``````````````
M$@````X"`````````````!(```!.```````````````2````H@(`````````
M````$@```%4``````````````!(```!=```````````````2````BP(`````
M````````$@```&4``````````````!(```!K```````````````2````=```
M````````````(````-X"`````````````!(```"0```````````````2````
ME0``````````````$@```/D!`````````````!$```"I`@`````````````2
M````.P(`````````````$@````0#`````````````!(```"<````````````
M```@````+0(`````````````$@```&,#`````````````!(```"T`@``````
M```````1````+0,`````````````$0```%\"`````````````!(````:`P``
M```````````2````+P,`````````````$0```+H``````````````!(````2
M`P`````````````2````90$`````````````$@```,,``````````````"(`
M``#2```````````````2````U@(`````````````$@```$L"````````````
M`!(```#7```````````````2````W0``````````````(````)8"````````
M`````!(```#W```````````````2````A0$`````````````$@```/P`````
M`````````"`````8`0`````````````2````>P(`````````````$@```'0!
M`````````````!(````>`0`````````````2````+P$`````````````$@``
M``D"`````````````!(```!F```````````````2````&@(`````````````
M$@```%0"`````````````!(````+`P`````````````2````-0$`````````
M````$@```/P"`````````````!(```!)`0`````````````2````!`(`````
M````````$@```,,!`````````````!(````W`P`````````````2````+`,`
M````````````(0```%`!`````````````!(````G`P``Z!,``-H!```2``H`
MU0$``#DZ```!````$@`+`*4#``!(+@``4P@``!(`"@`S!```ESD``%X````2
M``H`@@,``%PI```%````$@`*`+0#````$````0```!(`!P#(`P``FS8``/P"
M```2``H`(00``&$I``"D`0``$@`*`/4#```DH````````!``%`"3`P``GRT`
M`*D````2``H`L@,``.DG```[````$@`*`+H#```F+0``2@```!(`"@#H`P``
M!2L``!4````2``H`+@0``'2P````````$``4`$@#``#=%0``,@```!(`"@`!
M!```&BL``*X````2``H`W@,``""@```$````$0`3`!H$```DH````````!``
M$P#Z`P``PA4````````0``H`40,``'`M```O````$@`*`&P#``!W*```Y0``
M`!(`"@`-!```R"L``%X!```2``H``&QI8G!E<FPN<V\`;W!E;F1I<@!S=&1E
M<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E96L`9V5T<&ED`'-T<F-M
M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I
M<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<F5A9&QI;FL`7U]C>&%?9FEN
M86QI>F4`97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E
M860`7U]R96=I<W1E<E]F<F%M95]I;F9O7V)A<V5S`')M9&ER`%]?97)R;F]?
M;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`9V5T
M=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)C+FUU<VPM>#@V+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H
M<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<F-H<@!S=')T;VL`<W1R
M;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`%]?<W1A8VM?8VAK
M7V9A:6P`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?
M7V)S<U]S=&%R=`!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A
M<E]F:6YD<')O9P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O
M<F5?<&5R;"]#3U)%`````,"?```(````S)\```@```#4GP``"`````"@```(
M````!*````@````(H```"`````R@```(````$*````@````4H```"````""@
M```(````Q)\```8#``#(GP``!@0``-"?```&'```V)\```8@``#<GP``!B0`
M`."?```&)P``Y)\```8K``#HGP``!B\``.R?```&-```\)\```8X``#TGP``
M!CH``/B?```&.P``_)\```9```#8G@``!P$``-R>```'`@``X)X```<%``#D
MG@``!P8``.B>```'!P``[)X```<(``#PG@``!PD``/2>```'"@``^)X```<+
M``#\G@``!PT```"?```'#@``!)\```</```(GP``!Q````R?```'$0``$)\`
M``<2```4GP``!Q,``!B?```'%```')\```<5```@GP``!Q8``"2?```'%P``
M*)\```<8```LGP``!QD``#"?```'&@``-)\```<;```XGP``!QT``#R?```'
M'@``0)\```<?``!$GP``!R$``$B?```'(@``3)\```<C``!0GP``!R4``%2?
M```')@``6)\```<I``!<GP``!RH``&"?```'+```9)\```<M``!HGP``!RX`
M`&R?```',```<)\```<Q``!TGP``!S(``'B?```',P``?)\```<U``"`GP``
M!S8``(2?```'-P``B)\```<Y``",GP``!SP``)"?```'/0``E)\```<^``"8
MGP``!S\``)R?```'00``H)\```="``"DGP``!T,``*B?```'1```K)\```=%
M``"PGP``!T8``+2?```'1P``N)\```=(``"\GP``!TH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#.@3!P``Z`4J``"#Q`S#````````````````````_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____H^@```!HN`$``.EP_/__
M_Z/L````:,`!``#I8/S___^C\````&C(`0``Z5#\____HQ`!``!FD/^C'`$`
M`&:0_Z,D`0``9I"-3"0$@^3P_W'\C4$(58GE5U:)SE/H#0(``('#RHH``%&#
M[`Q0C4$$4%'H6?[__XN#,`$``(/$#%!0_[,L`0``Z-/\__^+@_P```"#Q!"+
MNPP!``"`.`!U-.B:_?__B8.D$0``A<!U"H/L#&H!Z";^__^#[`Q0Z'W^__]9
M_S?H]?[__X/$$,:`404```"#[`S_-^CA_O__@(CJ`@```EK_-^C2_O__@\00
M@(CJ`@```8L&@\`%/?___S]V%%!0C8-[H?___[,4`0``4.CX^___@^P,P>`"
M4.C\_?__BWX$@\00N0$```")@Y@1``#'@YP1```$````BQ>)$(V3Z:/__XE0
M!(N35`$``(E0"(V3[*/__XE0#(L6.<I^"HLTCXETB`Q!Z_*#[`S'1)`,````
M`(/"`VH`4(V#6(G__U)0_[.D$0``Z$[\__^#Q"")QH7`=1.#[`S_LZ01``#H
M5_W__X/$$(G&@^P,_[.D$0``Z-3\__^-@\FA___H;PX``(/$$(7`=3"#NZ`1
M````=1&-@WZA___H5`X``(F#H!$``(N#H!$``(7`=`R#[`Q0Z/PC``"#Q!"#
M[`S_LZ01``#HY/W__^B?^O__@\00C67PB?!96UY?78UA_,,Q[8G@@^3P4%#H
M`````($$)"R(``!0Z`````!3Z"P```"!P^F(``"#[!"+1"08:@"-4`3_LP`!
M``#_LP@!``!2_S#_L_0```#H,?S__XL<),/H2@$```6TB```C8A8`0``C9!8
M`0``.<IT&(N`!`$``(7`=`Y5B>6#[!11_]"#Q!#)P\/H&P$``('!@8@``%6)
MY5:^`@```%.-F5@!``"-@5@!```IV,'X`IGW_H7`=!.+D2`!``"%TG0)45%0
M4__2@\00C67X6UY=PU6)Y5=64^AW____@<,TB```@^P,@+MT`0```'5I@[L<
M`0```'01@^P,_[,T`0``Z!?]__^#Q!"-LRC___^-NRS___\I]\'_`D^+@W@!
M```Y^',,0(F#>`$``/\4ANOJZ"+___^#NQ`!````=!*#[`R-@X#A__]0Z,?\
M__^#Q!#&@W0!```!C67T6UY?7<-5Z`````!:@<*KAP``B>53Z-_^__^!PYR'
M``!0@[LD`0```'09C8-\`0``4FH`4(V#@.'__U#HBOS__X/$$(M=_,GIY/[_
M_XL$),.+#"3#53'25U93@>Q\`0``B40D"&6A%````(F$)&P!```QP(M$)`B+
M3)`<C40D+`_)B0R00H/Z$'7IC8PD+`$``(M0-#-0((/`!#-0!#-0_-'"B5`\
M.<AUZ(M$)`B+`(E$)!"+1"0(BU0D$(M`!,'*`HE$)!B+1"0(BTPD&(M`",')
M`HE$)`R+1"0(BWPD#(ML)`R+0`PQSR-\)!`S?"0,B40D%(M$)`B+0!")1"0<
MBT0D+(M<)!R-M`.9>8):BT0D$(M<)!3!P`4!\(MT)`PS="04(W0D&#-T)!0!
MQHM$)#"-A`.9>8):B<L!QXGP,=/!P`4A\\'.`@''BT0D-#'+C80%F7F"6HML
M)#@!PXGXP<`%C8PIF7F"6HML)#P!PXG0,?`A^,'/`C'0C90JF7F"6HML)$`!
MR(G9P<$%`<B)\3'Y(=DQ\8VT+IEY@EJ+;"1$`=&)PL'"!<'+`@'1B?HQVB'"
MP<@",?J-O"^9>8):BVPD2`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD
M3`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-M"Z9>8):BVPD4`'9B</!PP4!V8G3
MB?K!RP(QVB'"P<@",?J-O"^9>8):BVPD5`'RB<[!Q@4!\HG&B=@Q\"'(,=B-
MG"N9>8):BVPD6`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-M"Z9>8):BVPD7`'9
MB</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9>8):BVPD8`'RB<[!Q@4!\HG&
MB=@Q\"'(,=B-G"N9>8):BVPD9`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-M"Z9
M>8):`=F)P\'#!0'9B=.)^L'+`C':(<+!R`(Q^HG%B=@!\HG.,>C!Q@4AR,')
M`@'RBW0D:#'8C;0WF7F"6HGO`?")UC'/P<8%(=?!R@(!\(MT)&PQ[XV<,YEY
M@EJ)S@'?B<,QUL'#!2'&P<@"`=^+7"1P,<Z-G!V9>8):BVPD=`'>B?O!PP6-
MC"F9>8):BVPD>`'>B=,QPR'[,=/!SP*-E"J9>8):`<N)\<'!!0'+B<$Q^2'Q
MP<X",<$!T8G:P<(%`=&+5"1\C800H>O9;HGZ,?(QVL'+`@'"B<C!P`4!PHN$
M)(````"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2$````P<\"C;0.H>O9
M;HG9,?DQT0'QB<;!Q@4!\8G6BY0DB````,'.`HV<$Z'KV6Z)^C'R,<(!VHG+
MP<@"P<,%`=J)PXN$)(P```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"20
M````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DE````,'.`HV<$Z'K
MV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$))@```"-O`>AZ]ENB?`QV#'(`?B)
MU\''!0'XB<^+C"2<````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0D
MH````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)*0```"-O`>A
MZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2H````P<\"C;0.H>O9;HG9,?DQT0'Q
MB<;!Q@4!\8G6BY0DK````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)
MPXN$)+````"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2T````P<\"C;0.
MH>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DN````,'.`HV<$Z'KV6Z)^C'R,<+!
MR`(!VHG+P<,%`=J)PXN$)+P```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+
MC"3`````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DQ````,'.`HV<
M$Z'KV6Z)^C'R,<+!R`*)Q0':BX0DR````(G+P<,%`=J-G`>AZ]ENB?`QZ#'(
M`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"3,````C;0^W+P;CXG/
M`?.)Q@G7P<8%`?.)_HG/(<8AU\'(`@GWB[0DT````(VT-=R\&X\!]XG>P<8%
M`?>)U@G&(=[!RP*)]8G6(<8)[HNL)-0```"-C"G<O!N/B=V)PP'.">N)^2'[
MP<$%`<Z)V8G#(>L)RXN,)-@```"-E`K<O!N/B>D!T\'/`HGR"?G!P@4A\0'3
MP<X"B<J)Z2'Y"=&+E"3<````C800W+P;CXGZ`<&)V`GRP<`%`<&)T(GZ(=@A
M\L'+`@G"BX0DX````(V$!=R\&X\!PHG(P<`%`<*)\`G8(<B)Q8GP(=@)Z(NL
M).0```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL).@`
M``"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<+!R`*)U8GZ(?()ZHNL).P`
M``"-G"O<O!N/`=J)R\'#!0':B<.)\`G8(<B)Q8GP(=@)Z(NL)/````"-O"_<
MO!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL)/0```"-M"[<O!N/
M`?&)QL'&!0'QB=:)^L'.`@GR(<*)U8GZ(?()ZHNL)/@```"-G"O<O!N/`=J)
MR\'(`L'#!0':B<.)\`G8(<B)Q8GP(=@)Z(NL)/P```"-O"_<O!N/`?B)U\''
M!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL)``!``"-M"[<O!N/`?&)QL'&!0'Q
MB=:)^L'.`@GR(<+!R`*)U8GZ(?()ZHNL)`0!``"-G"O<O!N/B<6)\`':">B)
MRR'(P<,%`=J)PXGP(>@)V(N<)`@!``"-G!_<O!N/`=B)T\')`L'#!0'8B>L)
MRXG?B>LAUR'+P<H""?N+O"0,`0``C;0^W+P;CP'SB<;!Q@4!\XG."=:)]XG.
M(<<AUL'(`@G^B[PD$`$``(V\/=R\&X\!_HG?P<<%`?Z)UPG'(=_!RP*)_8G7
M(<<)[XNL)!0!``"-C"G<O!N/`?F)]\''!0'YB<<)WR'WB?V)QR'?">^+K"08
M`0``C90JW+P;CP'7B<K!S@+!P@4!UXN4)!P!``"-E!#6P6+*B=@Q\#'(P<D"
M`=")^L'"!0'0BY0D(`$``(V<$];!8LJ)\C'*,?K!SP(!VHG#P<,%`=J+G"0D
M`0``C;0>UL%BRHG+,?LQP\'(`@'SB=;!Q@4!\XG&BX0D*`$``(V,`=;!8LJ)
M^#'P,=`!R(G9P<$%`<B)T8N4)"P!``#!R0*-E!?6P6+*B?<QSS'?`=>)PL'"
M!0'7BY0D,`$``,'+`HVT%M;!8LJ)RC':,<+!R`(!\HG^P<8%`?*)QHN$)#0!
M``"-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`!0'!BX0D.`$``(V<`];!8LJ)\#'X
M,=`!V(G+P<,%`=B)TXN4)#P!``"+;"00P<L"C906UL%BRHG^,=XQSL')`@'6
MB<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQRC'"P<@"`?J)]\''!0'ZB<>+A"1$
M`0``C80#UL%BRHG+,?LQ\\'.`@'#B=#!P`4!PXN$)$@!``"-C`'6P6+*B?@Q
M\#'0`<B)V<'!!0'(B=&+E"1,`0``P<D"C907UL%BRHGW,<\QW\'+`@'7B<+!
MP@4!UXN4)%`!``"-M!;6P6+*B<HQVC'"P<@"`?*)_L'&!0'RB<:+A"14`0``
MC80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!P8N$)%@!``"-G`/6P6+*B?`Q^#'0
M`=B)R\'#!0'8B=.+E"1<`0``P<L"C906UL%BRHG^,=XQSL')`@'6B<+!P@4!
MUHN4)&`!``"-O!?6P6+*B=HQRC'"P<@"`?J)]\''!0'ZB[PD9`$``(V\.];!
M8LJ)RS'#,?/!S@(!^XG7P<<%`?N+O"1H`0``C;P]UL%BR@'/B<$Q\0-T)!0Q
MT<'*`@-4)`P!^8G?`UPD&,''!0'YBWPD"`-$)!R)#XE?!(E7"(EW#(E'$(N$
M)&P!``!E,P44````=`7HOA8``('$?`$``%M>7UW#55=6,?93Z+[R__^!PWM[
M``"#[!R%P'1NBXL8`0``B<6+,8ET)`0Q]H-\)`0`=%>*30"$R70(@/D]=`-%
MZ_&+?"0$B<$IQ8LWA?9T.HE4)`Q055&)3"045NC-[?__@\00BTPD"(M4)`R%
MP'45@#PN/74/*WPD!(UT+@'!_P*).NL%@\<$Z\"#Q!R)\%M>7UW#@^P<98L-
M%````(E,)`PQR8U4)`CH5____XM,)`QE,PT4````=`7H^!4``(/$',/HZQ4`
M`('"PGH``%93B<.#[!1EH10```")1"0,,<"+LA@!``"-5"0(B=CH$O___X7`
M=!>+!HM4)`B-!)"+4`2)$(72=-^#P`3K\HM$)`QE,P44````=`7HF!4``(/$
M%%M>PU575E/HG_'__X'#7'H``(/L+(D$)(E4)`1EH10```")1"0<,<"`.CUU
M!/]$)`2#S?\Q]OR+?"0$B?")Z8U4)!CRKO?1C4'_B40D"(L$).B,_O__B<*%
MP'0OB>F)QXGP\JZ)S??533ML)`@/@JH````QP(M\)`2*#`>(#`)`A,EU\3'`
MZ1$!``"+@Q@!```Q]HL0@SRR`'0#1NOW@[N4$0```(T\M0@```!T(%%15U+H
M1>O__XN3&`$``(/$$(D"A<!U0X/(_^G.````B50D#(/L#%?'@Y01```!````
MZ`?L__^#Q!")Q87`=-A0C4?X4(M4)!125>C^Z___BX,8`0``@\00B2B+@Q@!
M``"+`,=$./P`````B70D&(L$)(H0A-)T"(#Z/70#0.ORB[,8`0``BTPD&(/L
M#"M$)`R+%HT\BHM,)!2-1`$"4.B:Z___@\00B0>%P`^$9____XL&BU0D&(L$
MD/\$)(L\)(U(`8I7_X@0@/H]=`B$TG0$B<CKY<8`/3'`BW0D!(H4!H@4`4"$
MTG7QZ>C^__^+?"0<93,]%````'0%Z.<3``"#Q"Q;7E]=PU575HG&4^CJ[___
M@<.G>```@>R,````9:$4````B40D?#'`A?8/A`P!``"`/@`/A`,!``"#[`Q6
MZ-GI__^#Q!")Q87`#X3M````@^P,5>B#ZO__@\00A<`/A,4```"#P!.)1"0(
MC8,UH?__4E)0_W0D%.A/ZO__@\00A<!TS%!0C8,TH?__4/]T)!3H-NK__X/$
M$(7`=+.#RO\QP/R)T8GW@^P,\JZ+?"04]]&)3"08B=&+5"08\JZ)R/?0C0P"
M4>AQZO___W0D&(G'C8,WH?__5E!7Z'WL__^#Q!B-1"0D4%?H+^S__X/$$$!T
M&8M$)"PE`/```#T`0```=0F)^.C\_O__ZPR#[`Q7Z!?J__^#Q!"#[`Q7Z.OK
M__^#Q!#I)____X/L#%7H6NK__XDT).BBZ___@\00BT0D?&4S!10```!T!>B6
M$@``@<2,````6UY?7<-6B<93Z)CN__^!PU5W``"#['QEH10```")1"1T,<"-
M1"044%;H^>G__X/$$(7`=3&+5"0<@>(`\```@?H`0```=`B!^@"@``!U&5!0
M:@)6Z+[H__^#Q!"%P`^4P`^VP.L",<"+3"1L93,-%````'0%Z!82``"#Q'1;
M7L-3Z"#N__^!P]UV``"#[!2+@PP!``#_,.A;Z___C9-(X/__4HV3/:'___^S
M*`$``%)0Z"'K__^#Q"A;PU93Z.3M__^!PZ%V``"#[!"+LPP!``#_-N@?Z___
MB00DZ*#___]8_S;H#^O__UJ-D^BC__]9:@!24HV3SY?__U*-DUFA__]24.@O
MZ/__@\0D6U[#55=64^B/[?__@<-,=@``@>P<(```9:$4````B80D#"```#'`
MZ##H__^#[`R-DVZA__]24(V#<J'__U!H`1```(UT)"96Z,_G__^#Q""-4`&!
M^@$0``!V`@\+A<!Y!#'VZV%2:``0``"-K"03$```55;H8^G__X/$$(G'A<!X
MWX/L#(U``5#H3NC__X/$$(G&A<!TRCGH<P>-!#@YQ7*Y.>YV"(U$/0`YQG*M
M@?\!$```?Z505U56Z$WJ___&!#X`@\00BXPD#"```&4S#10```")\'0%Z*@0
M``"!Q!P@``!;7E]=P^D6____55=64^BE[/__@<-B=0``@>R,$```BY0DI!``
M`(NT)*`0``")5"0(9:$4````B80D?!```#'`C8-^H?__Z#3Z__^)1"0$4%!J
M+U;H4.C__X/$$(M4)`B%P'02B?*-@X>A___HG_K__^D6`0``_#'`@\G_B?>-
MJY2A___RKO?1C4'_B40D"%!055+H8>G__X/$$(G"A<!TPX`Z`'4&C9,UH?__
M@WPD!`!T'U!04HE4)!C_="00Z,;F__^#Q!"+5"0,A<`/A+````"#R?\QP(G7
M\J[WT4F`?`K_+W4'2<8$"@#K\HM$)`B-1`@!/?\/```/CV7___^-@Y:A__]7
M5U90C8.%HO__4E!H`!```(V\))@```!7Z!;F__^#Q"!`/0`0``!V`@\+45&-
M1"0D4%?HG.C__X/$$(7`=3Z+1"0L)0#P```]`(```'4N4E)J`5?HR^7__X/$
M$(7`=1V)^HV#AZ'__^B>^?__@^P,5^C>YO__@\00B<;K"E!056H`Z0?___^)
M\(NT)'P0``!E,S44````=`7H_PX``('$C!```%M>7UW#BU0D!(G0B@J$R70(
M0H#Y+W7TZ_##5U93BU0D$.CIZO__@<.F<P``A=)T/(`Z`'0W_#'`@\G_B=?R
MKHG.]]:-1#+^.<)S&(`X+W4)2.OTB<@YRG,*@#@OC4C_=?+K+3G"=2F`.B]U
M"X/L#(V#-:'__^L)@^P,C8.6H?__4.@JYO__@\00ZSF`."]U!4@YPG+V*="-
M2`*!^0`0``!W($`]`!```'8"#PN-LY0!``!14%)6Z*7F__^#Q!")\.L",<!;
M7E_#5[DB````5E/H.NK__X'#]W(``(/L,&6A%````(E$)"PQP(U\)`J-LR3@
M___\\Z2-@YBA___H`_C__XV#H:'__^CX]___C8.IH?__Z.WW__^-@[*A___H
MXO?__XV#N:'__^C7]___C8/)H?__Z,SW__^-@WZA___HP??__XV#U:'__^BV
M]___C8/?H?__Z*OW__^-@^FA___HH/?__XV#AZ'__^B5]___C8/SH?__Z%OW
M__^%P'0-B<*-@]^A___HV_?__XV#!*+__^@_]___A<!T#8G"C8,6HO__Z+_W
M__^-@R&B___H(_?__X7`=`J)PHV#?J'__^LVC8,QHO__Z`KW__^)PH7`=1]0
MC8-"HO__:@I0C40D)U#HBN3__X/$$(7`=0^-5"0EC8/5H?__Z&OW__^-DTVB
M__^-@[FA___H6O?__XM$)"QE,P44````=`7HV@P``(/$,%M>7\-3Z./H__^!
MPZ!Q``"#[`B#NU`!``#_=2>-@]6A___HC?;__S'2A<!T$(H`/#`/E<$QTH3`
M#Y7"(<J)DU`!``"+@U`!``"#Q`A;PU/HF>C__X'#5G$``(/L".@\YO__@^P,
M4.B3Y/__@\00,=*%P'0"BQ"#Q`B)T%O#55=64^AGZ/__@<,D<0``@^P<BW0D
M,(V#3Z+__^@6]O__A<!T!X`X`(G%=0V)\HV#3Z+__X/$'.M?4%!65>COX___
M@\00A<!U6(/*__R)T8GW@^P,\JZ)[_?1B4PD&(G1BU0D&/*NB<CWT(T,`E'H
M/N/__XDL)(G'C8.4H?__4(V#A:+__U905^A$Y?__B?J-@T^B__^#Q#Q;7E]=
MZ2?V__^#Q!Q;7E]=PU6Y!@```%=64^BYY___@<-V<```@>Q<@0``BX0D<($`
M`(V\))0```")1"0(C;,X`0``9:$4````B80D3($``#'`C8-FHO__QX0DA```
M``````")1"1\C8,UH?__B80D@````/SSI8V#:Z+__\>$))``````````B80D
MB````(V#<*+__XF$)(P```"-@WZA___H^/3__X7`="&`.`")QG0:@^P,4.BM
M_O__B30DZ+;B__^)1"00Z7('``#H:/[__XV\)(@```")QH7`=3.+!X7`="?H
MMO3__X7`=06#QP3K[(`X`'3V@^P,4.AYXO__@\00B<:%P'3DZP:-LU^B__\Q
MP(GW@\G_@^P,\JZ)RO?2C402_U#H[N'__X/$$(G%B<</M@:$P'084490C8-Y
MHO__4%>#QP+H[>/__X/$$.OAC;PDE````(LWA?9T,(GPZ#KT__^)QH7`=!Z`
M.`!T&>C"]___A<!T$(/L#%;H]^'__X/$$(G&ZP6#QP3KRHU\)'R%]G4OBQ>%
MTG0I@#H`="2)T(D4).B,]___BQ0DA<!T#H/L#%+HON'__X/$$(G&@\<$Z\TQ
MP(/)_XGW@^P,\JZ)[_?1B<J#R?_RKHG(]]"-O`("!```5^@LX?__B40D%%B-
M@WZB__]:58VKEJ'__U"-@X.B__]55E#_="0@Z";C__^#Q!AHP`$``/]T)!#H
MM>+__X/$$$!U-^B:XO__@S@1="WHD.+__X/L#/\P_W0D%(M$)!S_,(V#C*+_
M_U"+@_@```#_,.C]X?__@\0@ZS]65HU$)"10_W0D$.CHX/__B40D'(/$$(-\
M)`P`="W_="0$BT0D#/\PC8/'HO__4(N#^````/\PZ+SA__^#Q!#'!"0`````
MZ94%``"+1"0L)0#P```]`$```'7#BW0D-.C$XO__.<9UMHM$)"PE_P$``#W`
M`0``=::#[`Q7Z#?@__^)1"00C8-:HO__Z*[R__^#Q!"%P'4(BT0D"(LPZR"#
M[`Q0Z'#@__]:65"+1"04_S#H$_C__X/$$(G&A<!TV(GW@\G_,<#RKHG*]]*-
M>O^#_P-V:%!0C8,:H___4(U$%OM0Z&'?__^#Q!"%P'5.@_\$=`>`?#[[+W5"
MBT0D"(M0!(72=#<QP(/)_XG7\J[WT8U!_X/X`W8DC8,?H___5U=0C40*^XE4
M)!10Z!G?__^#Q!"%P'4&BU0D"(G6Z$W[__^)1"0(A<`/A?`#``!146H`5NC1
MW___@\00B<:%P`^$V0,``&H":O]J[E#HN-[__X/$#&H&C;PD5`$``%=6Z+7@
M__^#Q!"`O"1,`0```'5:@+PD30$``$-U4("\)$X!``!!=4:`O"1/`0``0W4\
M@+PD4`$``$AU,H"\)%$!``!%=2AJ`FK_:L96Z%K>__^#Q`QJ*5=6Z%[@__]8
MC8/HH___6E!75>DZ`P``:@!J`&H`5N@RWO__QX0DO`````$C16?'A"3`````
MB:O-[\>$),0```#^W+J8QX0DR````'94,A#'A"3,````\.'2P\>$)-``````
M````QX0DU`````````#'A"08`0```````(/$$%=H`(```(V$)%0!``!05NC3
MW___@\00B<>%P`^.;@$``(T$_0`````#A"3`````<P?_A"3$````BXPD"`$`
M`(F$),````")^,'H'0&$),0```"%R0^$@@```+A`````B?HIR#G'?@*)PHV,
M#,@```"-A"1,`0``.<%S!XTL$3GH<@HYP78(`=`YP7,"#PN!^@"```!W]E!2
MC:PD5`$``(E4)!154>CMW___BX0D&`$``(M4)!P!T(F$)!@!``"#Q!"#^$`/
MA3;___^-A"2L````*=<!U>BGX___ZP>-K"1,`0``@_\_?ER-A"0(`0``.>AV
M"XV$),@````YZ'*.C80DR````#G%<PN-34`YR`^">/___U"#[T!J0%6#Q4"-
MA"2X````B40D&(V$)-0```!0Z&'?__^+1"0<Z$+C__^#Q!#KGXV$),@````Y
MQ78+C0PX.<T/@C+___\YQ7,,C4P]`#G(#X(B____@_]$#X<9____4%=5C80D
MU````%#H%-___XF\)!@!``#I;O[__X/L#%;H+][__XN4)-````"+M"34````
MB=7!Z@,/SH/B/P_-C4(!QH04V````("#Q!"#^#A^.+I`````42G"4FH`C;PD
MU````(V,)+@````!^(E,)!A0Z$W<__^+1"0<Z([B__^#Q`QJ.&H`5^L34KHX
M````*<)2:@"-A`34````4.@BW/__@\00C80DK````(FT)``!``")K"0$`0``
MZ$_B__^+A"2L````#\B)A"0/`0``BX0DL`````_(B80D$P$``(N$)+0````/
MR(F$)!<!``"+A"2X````#\B)A"0;`0``BX0DO`````_(B80D'P$``%6+1"0,
M#[:$!!,!``!0C8-YHO__4(M$)!0!P(VT)"\!```!\%#HV]W___]$)!B#Q!"#
M?"0(%'7(C8/HH___QH0D2P$```!75U"-@Y:A__]64(V#)*/___]T)!A0_W0D
M'.B@W?__@\0@ZWN-DTVB__^-@]6A___H@>[__^CEVO__C9/HH___5E924(V#
M,Z/__U7_="084/]T)!SH9MW__X/$(%)2:,`!``#_="0,Z//<__^#Q!!`=2WH
MV-S__X,X$74C_T0D#.B:VO__C9/HH___45+_="044(V#0:/__U7_="08Z["#
M[`S_="00Z,3<__^+5"00C8-^H?__Z/SM__]8_W0D#.@J]___@\00BXPD3($`
M`&4S#10```"+!"1T!>AI`P``@<1<@0``6UY?7<-55U93Z&O?__^!PRAH``"#
M["B+LPP!``#_-NBFW/__7?\VB<?HG-S__XI79(A098V#N:'__^@![?__@\00
MA<!T"X`X,74&@'@!`'0%Z-ST__^#[`S_-NAJW/__C9->H___:@MJ`5)0Z.G:
M__^#Q""%P'4M@^P,_S;H2-S__XV38Z/__VH#:@%24.C'VO__@\0@B<>%P`^%
MS````.D+`0``BT`,OP$```"+:!B-1_^)1"0(BP8YNYP1``!^'8/L#%#H`-S_
M_VH`_W0D'%50Z*/9__^#Q""%P'44BX.<$0``2#M$)`AUC;\!````ZU2+$(M"
M""4`!"``/0`$``!U!8M"#.L@B50D#(/L#/\VZ+3;__]J`FH`BU0D)%)0Z.7;
M__^#Q"!145"+@Y@1``#_-+CH$=G__X/$$(7`=9Y'Z6K___^+!CF[G!$```^.
M)/___X/L#$=0Z&S;__]96E50Z$/8__^#Q!#KVHM`#(/L#(LH_S;H3]O__X/$
M#(V39:/__U)54.CNV?__BT<,@\00BSCV1PI`=!:#[`S_-N@FV___75I74.CM
MV/__@\00@^P,_S;H$-O__XV3:J/__VH#:@%24.B/V?__@\0@B<6%P'1GC8.'
MH?__Z&'K__^)QX7`=`6+10SK-^CR[___A<")QXM%#'0A@^P,BRC_-NC&VO__
M@\0,5U50Z&O9__^)/"3H<]K__^L?BY.8$0``BSJ+*(/L#/\VZ)W:__^#Q`Q7
M55#H0MG__X/$$(/L#/\VZ(7:__^#Q`R-DVRC__]J`5)0Z(/7__]:_S:)Q^AI
MVO__@\0,C9.!H___4E=0Z`C9__]9_S;H4-K__\9`90"-@WZA___HM^K__X/$
M$(F#H!$``(7`=2:#[`S_LY@1``#H#O7__X/$$(F#H!$``(7`=0N#[`R-@X>C
M___K-U!0:,`!``#_LZ`1``#HK-G__X/$$(U0`8/Z`78@@_@1=!M0BX.8$0``
M_[.@$0``_S"-@ZBC__]0Z"'7__^#Q!Q;7E]=PU=64XMT)!#H;-S__X'#*64`
M`(/L#%;H:/'__XD$).A+\?__@\00B<?H8O/__X7`="F%]G0E@#X`="!04(V#
M?J+__U!7Z/#7__^#Q!`Y^'4*6XGP7E_I*>S__UM>7\.+%"3#4^@0W/__@</-
M9```@^P(Z*/9__^#Q`A;P^A+W?__!;5D``!5B>534HV8(/___XL#@_C_=`?_
MT(/K!.OR6%M=PX/L#.A,W/__@\0,PP``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``
M55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`
M+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,`5$5-4$1)4@!435``05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`T-P!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB
M.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*
M<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*
M?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q
M,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@
M:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@
M9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N
M<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F
M86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O
M9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S
M="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T
M(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I
M9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F
M<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD
M9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N
M+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D
M:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB
M+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N
M86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D
M92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE
M(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O
M<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@
M(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@
M4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P
M;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L
M87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R
M(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV
M*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L
M("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?
M4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U
M8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W
M<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M
M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*
M;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN
M*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL
M92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%
M*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A
M<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I
M;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H
M*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE
M7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D
M0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H
M<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA
M;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B
M/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H
M+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D
M9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O
M7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B
M8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD
M)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E
M;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM
M>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D
M9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P
M96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E
M("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT
M96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI
M;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@``7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````<&5R
M;'AS:2YC`````1L#.]@````:`````)'___0```"PE/__&`$``,B4__^,#```
M2IC__RP!```FI/__;`$``+:D__^X`0``Y:3__]`!``!'I?___`$``/JF__]L
M`@``3JC__S0#``#)J/__@`,```2I__^P`P``5ZG___P#```\JO__B`0``$&J
M__^<!```Y:O__X`%``#ZJ___E`4``*BL___@!0``!J[__R0&``!0KO__1`8`
M`'^N__]P!@``**____`&``![M___M`H``'>Z__\X#```U;K__]0,``#9NO__
MZ`P``!0``````````7I2``%\"`$;#`0$B`$``"`````<````!)#__[`#````
M#@A&#@Q*#PMT!'@`/QH[*C(D(A````!`````D)/__Q@`````````/````%0`
M```6E___W`L```!!#@B%`D,.#(<#00X0A@1!#A2#!48.D`,#RPL.%$'##A!!
MQ@X,0<<."$'%#@0``$@```"4````LJ+__Y``````00X(A0)!#@R'`T$.$(8$
M0PX4@P5.#C!]#C1!#CA!#CQ%#D!(#C!I#A1#PPX00<8.#$''#@A!Q0X$```4
M````X````/:B__\O`````$,.(&L.!``H````^`````VC__]B`````$P."(8"
M00X,@P-%#B`"30X,0<,."$'&#@0``&P````D`0``0Z/__[,!````00X(A0)!
M#@R'`T$.$(8$00X4@P5.#D`"F@Y$00Y(00Y,00Y03@Y`50Y,00Y04@Y`1PY$
M1`Y(10Y,00Y03@Y`=`Y,4@Y02`Y``EP.%$'##A!!Q@X,0<<."$'%#@0```#$
M````E`$``(:D__]4`0```$$."(4"00X,AP-!#A"&!$,.%(,%40Z@`6`.K`%!
M#K`!2`Z@`4T.K`%!#K`!2`Z@`58.I`%!#J@!00ZL`40.L`%(#J`!10ZD`4$.
MJ`%'#JP!1`ZP`4@.H`%1#JP!7`ZP`4D.M`%)#K@!00Z\`4$.P`%(#J@!10ZL
M`4$.L`%(#J`!7PZL`4$.L`%(#J`!0PZL`4$.L`%(#J`!2`ZL`4$.L`%0#J`!
M6`X40<,.$$'&#@Q!QPX(0<4.!$@```!<`@``$J7__WL`````00X(A@)##@R#
M`TX.B`%1#HP!00Z0`4@.@`%?#H0!00Z(`4(.C`%!#I`!2`Z``6$.#$'##@A!
MQ@X$```L````J`(``$&E__\[`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP
M2`X(0<,.!`!(````V`(``$RE__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"
M#B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!```B````"0#
M``!3I?__Y0````!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L$!7#KQ`1P[`0$$.
MQ$!'#LA`10[,0$4.T$!(#K!`5@ZT0$4.N$!(#KQ`00[`0$@.L$!)#KQ`1`[`
M0$@.L$!F#K1`00ZX0$$.O$!!#L!`3`ZP0%T.%$'##A!!Q@X,0<<."$'%#@00
M````L`,``*RE__\%`````````.````#$`P``G:7__Z0!````00X(A0)!#@R'
M`T$.$(8$00X4@P51#J`A<0ZD(4$.J"%"#JPA00ZP(4@.H"%T#J0A00ZH(4$.
MK"%!#K`A2`Z@(5D.I"%!#J@A00ZL(4@.L"%(#J`A`D`.I"%!#J@A00ZL(4$.
ML"%'#K0A00ZX(44.O"%(#L`A2`Z@(4L.I"%!#J@A10ZL(4$.L"%(#J`A50ZD
M(4$.J"%"#JPA00ZP(4@.H"%4#JPA00ZP(4@.H"%%"@ZD(4$.J"%!#JPA0@ZP
M(44+70X40<,.$$'&#@Q!QPX(0<4.!!````"H!```7:;__Q4`````````2```
M`+P$``!>IO__K@````!!#@B'`D$.#(8#00X0@P0"4@H.'$@+0PX<1PX@2`X0
M:@X400X800X<00X@2`X01\,.#$'&#@A!QPX$`$`````(!0``P*;__UX!````
M00X(AP)&#@R&`T$.$(,$3@Y``O4.1$@.2$$.3$4.4$@.0'D.$$'##@Q!Q@X(
M0<<.!```'````$P%``#:I___2@````!!#@B#`DX.$'D."$'##@0H````;`4`
M``2H__\O`````$$."(,"3@X02`X<00X@2`X02PX(0\,.!````'P```"8!0``
M!ZC__ZD`````00X(A0)!#@R'`T$.$(8$00X4@P5.#C!E"@X40@M!#C1!#CA!
M#CQ!#D!(#C!/#CQ:#D!1#D1'#DA!#DQ!#E!0#A1!PPX00<8.#$''#@A!Q0X$
M10XP@P6%`H8$AP-##A1!PPX00<8.#$''#@A!Q0X$P`,``!@&```PJ/__4P@`
M``!!#@B%`D8.#(<#00X0A@1!#A2#!5$.\(("`HH*#OR"`D$.@(,"5@MN#OR"
M`D$.@(,"2`[P@@)8#OR"`DL.@(,"2`[P@@),#O2"`D(.^(("1P[\@@)!#H"#
M`DL.\((";0[\@@)!#H"#`D@.\(("<`[\@@)!#H"#`D@.\(("40[\@@)9#H"#
M`DH._(("1P[X@@)!#OR"`D<.@(,"1PZ$@P)!#HB#`D$.C(,"1`Z0@P)(#OB"
M`D4._(("1`Z`@P)(#O""`E4._(("0@Z`@P)$#H2#`D8.B(,"1PZ,@P)(#I"#
M`D@.\(("0P[T@@)!#OB"`D4._(("1`Z`@P),#O""`DL.](("1@[X@@)'#OR"
M`D@.@(,"2`[P@@)\#OR"`D$.@(,"5P[P@@)/#OR"`D$.@(,"1@[\@@)!#OB"
M`D$._(("1@Z`@P)(#O""`EP.](("00[X@@)'#OR"`D4.@(,"2`[P@@)U#O2"
M`D$.^(("00[\@@))#H"#`D@.\(("7`H.](("00[X@@)"#OR"`D$.@(,"2`[P
M@@),#O2"`D(.^(("0@[\@@)!#H"#`D@.](("0@[X@@)(#OR"`D$.@(,"2`[P
M@@)^#O2"`D(.^(("0@[\@@)!#H"#`D@.](("0@[X@@)!#OR"`D$.@(,"1@[\
M@@)'#OB"`D$._(("00Z`@P)!#H2#`D4+0@[T@@)"#OB"`D(._(("00Z`@P("
M8`[P@@)!#O2"`D4.^(("2`[\@@)!#H"#`D@.\(("`H`.](("00[X@@),#OR"
M`D$.@(,"7`[P@@("5`[T@@)%#OB"`D$._(("5@Z`@P)1#O""`G(*#O2"`D$.
M^(("00[\@@)(#H"#`E$+0PH._(("00Z`@P)M#O""`DL.](("0P[X@@)"#OR"
M`E4.@(,"40[T@@)"#OB"`D(._(("00Z`@P)""T$.](("2`[X@@)"#OR"`D@.
M@(,"2`[P@@(":P[T@@)-#OB"`D<._(("4`Z`@P),#O""`E8.](("00[X@@)!
M#OR"`D<.@(,"00Z$@P)*#HB#`D$.C(,"1`Z0@P)(#O""`E\.](("00[X@@)!
M#OR"`D$.@(,"1PZ$@P)$#HB#`D$.C(,"1`Z0@P)(#O""`D$.](("00[X@@)%
M#OR"`D0.@(,"2`[P@@)=#O2"`D$.^(("1`[\@@)!#H"#`D<.A(,"1`Z(@P)"
M#O""`D,._(("1`Z`@P)5#OR"`D0.@(,"2`[P@@)>#A1!PPX00<8.#$''#@A!
MQ0X$`(`!``#<"0``OZS___P"````00X(A0)!#@R'`T$.$(8$00X4@P5.#CQ(
M#D!&#CQ"#D!;#C!7#CQ"#D!-#D1"#DA!#DQ!#E!(#C!'#CQ"#D!-#D1"#DA!
M#DQ!#E!(#C!N#CQ!#D!'#D1$#DA!#DQ!#E!(#C!U#CQ"#D!'#D1"#DA%#DQ!
M#E!(#C!!#C1!#CA!#CQ)#D!(#C!;#CQ"#D!&#CQ!#CA!#CQ!#D!(#C!(#CQ$
M#D!(#C1'#CA!#CQ!#D!+#C!+#CQ"#D!&#CQ!#CA!#CQ!#D!(#C!##CQ"#D!-
M#D1"#DA!#DQ!#E!(#C!M"@X\1`Y`2`XT00XX00X\00Y`3PM-#CQ"#D!(#C1!
M#CA!#CQ!#D!(#C!#"@X\0@Y`2`XT2`XX00X\00Y`1@X\0@Y`2@XT1PXX00X\
M00Y`1@X\0@Y`5PXP30X\1@Y`2`XP30X\2`M!#C1!#CA%#CQ&#D!(#C!.#C1,
M#CA"#CQ'#D!%#C!##A1!PPX00<8.#$''#@A!Q0X$``!0````8`L``#>N__]>
M`````$$."(<"00X,A@-!#A"#!%(.'$$.(%`.$%4.%$$.&$<.'$$.($@.$$4*
MPPX,0\8."$''#@1%"T'##@Q!Q@X(0<<.!`!$````M`L``#2(___:`0```$0,
M`0!*$`4"=0!$$`<"=7P0!@)U>$,0`P)U=$P/`W5P!@.Q`<$,`0!!PT'&0<=!
MQ4,,!`0````0````_`L``/FM__\$`````````!P````0#```Z:W__QD`````
M00X(@P).#A!(#@A!PPX$````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_____`````/____\``````0````$````!````
MPP(```\````_!```#``````0```-````.3H``/7^_V^,`0``!0```%@(```&
M````2`(```H```!=!```"P```!`````5``````````,```#,G@```@```-`!
M```4````$0```!<```!P#0``$0```+@,```2````N````!,````(````&```
M``````#[__]O`0``"/K__V\*````````````````````````````````````
M`````````````````````/R=`````````````#80``!&$```5A```&80``!V
M$```AA```)80``"F$```MA```,80``#6$```YA```/80```&$0``%A$``"81
M```V$0``1A$``%81``!F$0``=A$``(81``"6$0``IA$``+81``#&$0``UA$`
M`.81``#V$0``!A(``!82```F$@``-A(``$82``!6$@``9A(``'82``"&$@``
MEA(``*82``"V$@``QA(``-82``#F$@``]A(```83```6$P``)A,``#83``!&
M$P``5A,``&83``!V$P``AA,``)83``"F$P``MA,``,83``#H$P``````````
M```Y.@`````````0````````````````````````````````````````````
M`````````````*```.)```#;0```'D(``/A````F0@```````/____^[0@``
M1T-#.B`H06QP:6YE(#@N,BXP*2`X+C(N,```+G-H<W1R=&%B`"YI;G1E<G``
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M``````````L````!`````@```'0!``!T`0``%P```````````````0``````
M```3````]O__;P(```",`0``C`$``+P````#``````````0````$````'0``
M``L````"````2`(``$@"```0!@``!`````$````$````$````"4````#````
M`@```%@(``!8"```700``````````````0`````````M````"0````(```"X
M#```N`P``+@````#``````````0````(````-@````D```!"````<`T``'`-
M``#0`0```P```!(````$````"````#\````!````!@`````0````$```$0``
M`````````````0`````````Z`````0````8````@$```(!```+`#````````
M`````!`````$````10````$````&````T!,``-`3```8```````````````(
M````"````$X````!````!@```.@3``#H$P``428``````````````0``````
M``!4`````0````8````Y.@``.3H```P```````````````$`````````6@``
M``$````"`````$````!````>/P`````````````$`````````&(````!````
M`@```"!_```@?P``W```````````````!`````````!P`````0````(```#\
M?P``_'\``#`,``````````````0`````````>@````$````#````[)T``.R-
M```(```````````````$`````````($````!`````P```/2=``#TC0``"```
M````````````!`````````"(````!@````,```#\G0``_(T``-`````$````
M``````0````(````20````$````#````S)X``,R.```T`0`````````````$
M````!````)$````!`````P````"@````D```)```````````````!```````
M``"7````"`````,```!`H```))```#00`````````````"``````````G```
M``$````P`````````"20```:```````````````!`````0````$````#````
@```````````^D```I0```````````````0``````````
